Codelens Directive
==================

The master repository for the css/js files from OnlinePythonTutor is https://github.com/pgbovine/OnlinePythonTutor

CSS:

modal-basic.css is the style for modal popups inside codelens
pytutor

JS:

All js files are from OPT.

If you want to make customizations for Runestone use the fork at https://github.com/bnmnetp/OnlinePythonTutor


